"""
Material Icons for Django CFG Unfold.

Provides IDE-friendly Material Design Icons constants.
"""

from .constants import IconCategories, Icons

__all__ = [
    'Icons',
    'IconCategories',
]
